==> vnctp-0.0.1.tar.gz: vnctp-0.0.1/setup.py <==
import sys
import os
import setuptools

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext

__version__ = '0.0.1'


class get_pybind_include(object):
    """Helper class to determine the pybind11 include path

    The purpose of this class is to postpone importing pybind11
    until it is actually installed, so that the ``get_include()``
    method can be invoked. """

    def __init__(self, user=False):
        self.user = user

    def __str__(self):
        import pybind11
        return pybind11.get_include(self.user)


ext_modules = [
    Extension(
        'vnctp.vnctpmd',
        ['src/vnctpmd.cpp'],
        include_dirs=[
            # Path to pybind11 headers
            get_pybind_include(),
            get_pybind_include(user=True),
        ],
        runtime_library_dirs=[os.path.join(sys.prefix, 'ctplib')],
        library_dirs=['ctplib'],
        libraries=['thostmduserapi_se'],
        extra_link_arg=['-Lctplib', '-lthostmduserapi_se'],
        language='c++',
    ),
    Extension(
        'vnctp.vnctptd',
        ['src/vnctptd.cpp'],
        include_dirs=[
            # Path to pybind11 headers
            get_pybind_include(),
            get_pybind_include(user=True),
        ],
        runtime_library_dirs=[os.path.join(sys.prefix, 'ctplib')],
        library_dirs=['ctplib'],
        libraries=['thosttraderapi_se'],
        extra_link_arg=['-Lctplib', '-lthosttraderapi_se'],
        language='c++'
    ),
]


# As of Python 3.6, CCompiler has a `has_flag` method.
# cf http://bugs.python.org/issue26689
def has_flag(compiler, flagname):
    """Return a boolean indicating whether a flag name is supported on
    the specified compiler.
    """
    import tempfile
    with tempfile.NamedTemporaryFile('w', suffix='.cpp') as f:
        f.write('int main (int argc, char **argv) { return 0; }')
        try:
            compiler.compile([f.name], extra_postargs=[flagname])
        except setuptools.distutils.errors.CompileError:
            return False
    return True


def cpp_flag(compiler):
    """Return the -std=c++[11/14/17] compiler flag.

    The newer version is prefered over c++11 (when it is available).
    """
    flags = ['-std=c++17', '-std=c++14', '-std=c++11']

    for flag in flags:
        if has_flag(compiler, flag): return flag

    raise RuntimeError('Unsupported compiler -- at least C++11 support '
                       'is needed!')


class BuildExt(build_ext):
    """A custom build extension for adding compiler-specific options."""
    c_opts = {
        'msvc': ['/EHsc'],
        'unix': [],
    }
    l_opts = {
        'msvc': [],
        'unix': [],
    }

    if sys.platform == 'darwin':
        raise NotImplementedError('MacOS/Darwin not supported!')

    def build_extensions(self):
        ct = self.compiler.compiler_type
        opts = self.c_opts.get(ct, [])
        link_opts = self.l_opts.get(ct, [])
        if ct == 'unix':
            opts.append('-DVERSION_INFO="%s"' % self.distribution.get_version())
            opts.append(cpp_flag(self.compiler))
            if has_flag(self.compiler, '-fvisibility=hidden'):
                opts.append('-fvisibility=hidden')
        elif ct == 'msvc':
            opts.append('/DVERSION_INFO=\\"%s\\"' % self.distribution.get_version())
        for ext in self.extensions:
            ext.extra_compile_args = opts
            ext.extra_link_args = link_opts
        build_ext.build_extensions(self)

setup(
    name='vnctp',
    version=__version__,
    packages=['vnctp'],
    author='Xiaoyong Guo',
    author_email='guoxiaoyong@guoxiaoyong.com',
    url='https://github.com/guoxiaoyong/vnctp',
    description='',
    long_description='',
    ext_modules=ext_modules,
    install_requires=['pybind11>=2.3'],
    setup_requires=['pybind11>=2.3'],
    cmdclass={'build_ext': BuildExt},
    zip_safe=False,
    data_files=[('ctplib', ['ctplib/libthostmduserapi_se.so', 'ctplib/libthosttraderapi_se.so'])]
)

==> vnctp-0.0.2.tar.gz: vnctp-0.0.2/setup.py <==
import sys
import os
import setuptools

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext

__version__ = '0.0.2'


class get_pybind_include(object):
    """Helper class to determine the pybind11 include path

    The purpose of this class is to postpone importing pybind11
    until it is actually installed, so that the ``get_include()``
    method can be invoked. """

    def __init__(self, user=False):
        self.user = user

    def __str__(self):
        import pybind11
        return pybind11.get_include(self.user)


ext_modules = [
    Extension(
        'vnctp.vnctpmd',
        ['src/vnctpmd.cpp'],
        include_dirs=[
            # Path to pybind11 headers
            get_pybind_include(),
            get_pybind_include(user=True),
            'src',
        ],
        runtime_library_dirs=[os.path.join(sys.prefix, 'ctplib')],
        library_dirs=['ctplib'],
        libraries=['thostmduserapi_se'],
        extra_link_arg=['-Lctplib', '-lthostmduserapi_se'],
        language='c++',
    ),
    Extension(
        'vnctp.vnctptd',
        ['src/vnctptd.cpp'],
        include_dirs=[
            # Path to pybind11 headers
            get_pybind_include(),
            get_pybind_include(user=True),
            'src',
        ],
        runtime_library_dirs=[os.path.join(sys.prefix, 'ctplib')],
        library_dirs=['ctplib'],
        libraries=['thosttraderapi_se'],
        extra_link_arg=['-Lctplib', '-lthosttraderapi_se'],
        language='c++'
    ),
]


# As of Python 3.6, CCompiler has a `has_flag` method.
# cf http://bugs.python.org/issue26689
def has_flag(compiler, flagname):
    """Return a boolean indicating whether a flag name is supported on
    the specified compiler.
    """
    import tempfile
    with tempfile.NamedTemporaryFile('w', suffix='.cpp') as f:
        f.write('int main (int argc, char **argv) { return 0; }')
        try:
            compiler.compile([f.name], extra_postargs=[flagname])
        except setuptools.distutils.errors.CompileError:
            return False
    return True


def cpp_flag(compiler):
    """Return the -std=c++[11/14/17] compiler flag.

    The newer version is prefered over c++11 (when it is available).
    """
    flags = ['-std=c++17', '-std=c++14', '-std=c++11']

    for flag in flags:
        if has_flag(compiler, flag): return flag

    raise RuntimeError('Unsupported compiler -- at least C++11 support '
                       'is needed!')


class BuildExt(build_ext):
    """A custom build extension for adding compiler-specific options."""
    c_opts = {
        'msvc': ['/EHsc'],
        'unix': [],
    }
    l_opts = {
        'msvc': [],
        'unix': [],
    }

    if sys.platform == 'darwin':
        raise NotImplementedError('MacOS/Darwin not supported!')

    def build_extensions(self):
        ct = self.compiler.compiler_type
        opts = self.c_opts.get(ct, [])
        link_opts = self.l_opts.get(ct, [])
        if ct == 'unix':
            opts.append('-DVERSION_INFO="%s"' % self.distribution.get_version())
            opts.append(cpp_flag(self.compiler))
            if has_flag(self.compiler, '-fvisibility=hidden'):
                opts.append('-fvisibility=hidden')
        elif ct == 'msvc':
            opts.append('/DVERSION_INFO=\\"%s\\"' % self.distribution.get_version())
        for ext in self.extensions:
            ext.extra_compile_args = opts
            ext.extra_link_args = link_opts
        build_ext.build_extensions(self)

setup(
    name='vnctp',
    version=__version__,
    packages=['vnctp'],
    author='Xiaoyong Guo',
    author_email='guoxiaoyong@guoxiaoyong.com',
    url='https://github.com/guoxiaoyong/vnctp',
    description='CTP binding extracted from vnpy',
    long_description='CTP binding extracted from vnpy',
    ext_modules=ext_modules,
    install_requires=['pybind11>=2.3'],
    setup_requires=['pybind11>=2.3'],
    cmdclass={'build_ext': BuildExt},
    zip_safe=False,
    data_files=[('ctplib', ['ctplib/libthostmduserapi_se.so', 'ctplib/libthosttraderapi_se.so'])]
)
